SystemOrganization addCategory: #ConfigurationOfVoyage!

Object subclass: #ConfigurationOfVoyage
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfVoyage'!

!ConfigurationOfVoyage class methodsFor: 'development support' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfVoyage class methodsFor: 'private' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfVoyage class methodsFor: 'private' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfVoyage class methodsFor: 'private' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfVoyage class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfVoyage class methodsFor: 'loading' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfVoyage class methodsFor: 'loading' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfVoyage class methodsFor: 'loading' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfVoyage class methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
project

	^self new project! !

!ConfigurationOfVoyage class methodsFor: 'development support' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfVoyage methodsFor: 'baselines' stamp: 'EstebanLorenzano 2/14/2012 13:31'!
baseline10: spec
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline. 
		spec repository: 'http://ss3.gemstone.com/ss/Voyage'.
		
		spec 
			project: 'Magritte2' with: [ 
				spec
					className: 'ConfigurationOfMagritte2';
					file: 'ConfigurationOfMagritte2';
					version: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'MongoTalk' with: [ 
				spec
					className: 'ConfigurationOfMongoTalk';
					file: 'ConfigurationOfMongoTalk';
					version: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];	
			package: 'Voyage-Model-Core';
			package: 'Voyage-Memory-Core' with: [ spec requires: 'Voyage-Model-Core' ];
			package: 'Voyage-Seaside-Container' with: [ spec requires: 'Voyage-Model-Core' ];
			package: 'Voyage-Mongo-Core' with: [ spec requires: #('MongoTalk' 'Voyage-Model-Core') ];
			package: 'Voyage-Mongo-Magritte' with: [ spec requires: #('Magritte2' 'Voyage-Mongo-Core') ].
			
		spec
			group: 'default' with: #('Core' 'Memory');
			group: 'Core' with: #('Voyage-Model-Core');
			group: 'Memory' with: #('Voyage-Memory-Core');
			group: 'Mongo' with: #('Voyage-Mongo-Core' 'Voyage-Mongo-Magritte') ].! !

!ConfigurationOfVoyage methodsFor: 'accessing' stamp: 'EstebanLorenzano 2/14/2012 13:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !
